==> ktp-text-ui-0.6.80.tar.bz2: ktp-text-ui-0.6.80/filters/images/ktptextui_message_filter_images.desktop.cmake <==
[Desktop Entry]
Name=Image Preview
Name[bs]=Pregled slike
Name[ca]=Vista prèvia d'imatge
Name[ca@valencia]=Vista prèvia d'imatge
Name[cs]=Náhled obrázku
Name[da]=Forhåndsvisning af billede
Name[de]=Bildvorschau
Name[el]=Προεπισκόπηση εικόνας
Name[es]=Vista previa de imagen
Name[et]=Pildi eelvaatlus
Name[fi]=Kuvan esikatselu
Name[fr]=Aperçu d'image
Name[gl]=Vista previa da imaxe
Name[hu]=A kép előnézete
Name[ia]=Vista preliminar de Imagine
Name[it]=Anteprima di immagini
Name[kk]=Кескінді қарау
Name[lt]=Paveikslėlio peržiūra
Name[mr]=प्रतिमा पूर्वावलोकन
Name[nb]=Bildeforhåndsvisning
Name[nl]=Afbeeldingsvoorbeeld
Name[pa]=ਚਿੱਤਰ ਝਲਕ
Name[pl]=Podgląd obrazu
Name[pt]=Antevisão da Imagem
Name[pt_BR]=Visualização de imagem
Name[ro]=Previzualizare imagine
Name[ru]=Просмотр изображений
Name[sk]=Náhľad obrázka
Name[sl]=Predogled slike
Name[sr]=Преглед слике
Name[sr@ijekavian]=Преглед слике
Name[sr@ijekavianlatin]=Pregled slike
Name[sr@latin]=Pregled slike
Name[sv]=Förhandsgranskning av bild
Name[tr]=Resim Önizlemesi
Name[ug]=سۈرەتنى ئالدىن كۆزەت
Name[uk]=Перегляд зображення
Name[wa]=Prévoeyaedje di l' imådje
Name[x-test]=xxImage Previewxx
Name[zh_CN]=图片预览
Name[zh_TW]=影像預覽
Encoding=UTF-8
Comment=Embed a thumbnail of any image URL sent in a chat
Comment[bs]=Unesite sličicu neke URL slike poslane u ćaskanju
Comment[ca]=Incrusta una miniatura de qualsevol URL d'imatge enviat al xat
Comment[ca@valencia]=Incrusta una miniatura de qualsevol URL d'imatge enviat al xat
Comment[cs]=Vložit náhled všem URL obrázků odeslaných do rozhovoru
Comment[da]=Indlejr en miniature af billed-URL'er sendt i chatten
Comment[de]=Vorschaubild jeder in einen Chat gesendeten Bildadresse einbetten
Comment[el]=Ενσωματώστε μια επισκόπηση οποιουδήποτε URL εικόνας που εστάλη σε συνομιλία
Comment[es]=Empotrar una miniatura de cualquier URL de imagen enviado en un chat
Comment[et]=Kõigi vestluses saadetud pildi-URL-ide näitamine pisipildina
Comment[fi]=Upota esikatselu keskusteluun lähetetyistä kuvaosoitteista
Comment[fr]=Intégrer une miniature de toute URL d'image envoyée dans un forum de discussions
Comment[gl]=Incrustar unha miniatura de calquera das URL de imaxes enviadas nas conversas
Comment[hu]=Bélyegkép beágyazása bármely képhivatkozáshoz, amelyet a csevegésben küldenek
Comment[ia]=Incorpora un miniatura de ulle URL de imagine inviate in un conversation
Comment[it]=Include miniature degli URL di immagini inviati in una chat
Comment[kk]=Чаттағы жіберілген кескін URL-інде нобайы болсын
Comment[lt]=Įjungti miniatiūras kiekvieno paveikslėlio URL atsiuntame pokalbyje
Comment[nb]=Bygg inn et minibilde av enhver bilde-URL sent i en prat
Comment[nl]=Een miniatuur of elke verzonden URL van een afbeelding inbedden in een chat
Comment[pl]=Osadź miniaturę jakiegokolwiek adresu URL obrazu w oknie rozmowy
Comment[pt]=Incorporar uma miniatura de qualquer URL de imagens numa conversa
Comment[pt_BR]=Insere uma miniatura de qualquer URL de imagem enviada no bate-papo
Comment[ro]=Înglobează miniatura oricărui URL de imagine trimis într-o discuție
Comment[ru]=Встраивание миниатюры при получение ссылки на изображение
Comment[sk]=Zahrnúť náhľad každej URL poslanej v rozhovore
Comment[sl]=Vstavi sličico kateregakoli poslanega naslova URL, ki je slika, v klepet
Comment[sr]=Угнежђена сличица било којег УРЛ‑а слике у ћаскању
Comment[sr@ijekavian]=Угнијежђена сличица било којег УРЛ‑а слике у ћаскању
Comment[sr@ijekavianlatin]=Ugniježđena sličica bilo kojeg URL‑a slike u ćaskanju
Comment[sr@latin]=Ugnežđena sličica bilo kojeg URL‑a slike u ćaskanju
Comment[sv]=Inbädda en miniatyrbild av alla webbadresser med bilder som skickas i en chatt
Comment[tr]=Sohbette gönderilmiş bir resim URL'sinin küçük resmini göm
Comment[uk]=Вбудовувати мініатюри для всіх адрес зображень, надісланих під час спілкування
Comment[wa]=Ravaler on prévoeyaedje di tolminme kén URL evoyî dins on berdelaedje
Comment[x-test]=xxEmbed a thumbnail of any image URL sent in a chatxx
Comment[zh_CN]=嵌入聊天中图像 URL 的缩略图
Comment[zh_TW]=聊天內傳送影像網址時嵌入其縮圖
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_images
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=images
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui_0.7.0.orig.tar.bz2: ktp-text-ui-0.7.0/filters/images/ktptextui_message_filter_images.desktop.cmake <==
[Desktop Entry]
Name=Image Preview
Name[bs]=Pregled slike
Name[ca]=Vista prèvia d'imatge
Name[ca@valencia]=Vista prèvia d'imatge
Name[cs]=Náhled obrázku
Name[da]=Forhåndsvisning af billede
Name[de]=Bildvorschau
Name[el]=Προεπισκόπηση εικόνας
Name[es]=Vista previa de imagen
Name[et]=Pildi eelvaatlus
Name[fi]=Kuvan esikatselu
Name[fr]=Aperçu d'image
Name[gl]=Vista previa da imaxe
Name[hu]=A kép előnézete
Name[ia]=Vista preliminar de Imagine
Name[it]=Anteprima di immagini
Name[kk]=Кескінді қарау
Name[lt]=Paveikslėlio peržiūra
Name[mr]=प्रतिमा पूर्वावलोकन
Name[nb]=Bildeforhåndsvisning
Name[nl]=Afbeeldingsvoorbeeld
Name[pl]=Podgląd obrazu
Name[pt]=Antevisão da Imagem
Name[pt_BR]=Visualização de imagem
Name[ro]=Previzualizare imagine
Name[ru]=Просмотр изображений
Name[sk]=Náhľad obrázka
Name[sl]=Predogled slike
Name[sr]=Преглед слике
Name[sr@ijekavian]=Преглед слике
Name[sr@ijekavianlatin]=Pregled slike
Name[sr@latin]=Pregled slike
Name[sv]=Förhandsgranskning av bild
Name[tr]=Resim Önizlemesi
Name[uk]=Перегляд зображення
Name[wa]=Prévoeyaedje di l' imådje
Name[x-test]=xxImage Previewxx
Name[zh_CN]=图片预览
Name[zh_TW]=影像預覽
Encoding=UTF-8
Comment=Embed a thumbnail of any image URL sent in a chat
Comment[bs]=Unesite sličicu neke URL slike poslane u ćaskanju
Comment[ca]=Incrusta una miniatura de qualsevol URL d'imatge enviat al xat
Comment[ca@valencia]=Incrusta una miniatura de qualsevol URL d'imatge enviat al xat
Comment[cs]=Vložit náhled všem URL obrázků odeslaných do rozhovoru
Comment[da]=Indlejr en miniature af billed-URL'er sendt i chatten
Comment[de]=Vorschaubild jeder in einen Chat gesendeten Bildadresse einbetten
Comment[el]=Ενσωματώστε μια επισκόπηση οποιουδήποτε URL εικόνας που εστάλη σε συνομιλία
Comment[es]=Empotrar una miniatura de cualquier URL de imagen enviado en un chat
Comment[et]=Kõigi vestluses saadetud pildi-URL-ide näitamine pisipildina
Comment[fi]=Upota esikatselu keskusteluun lähetetyistä kuvaosoitteista
Comment[fr]=Intégrer une miniature de toute URL d'image envoyée dans un forum de discussions
Comment[gl]=Incrustar unha miniatura de calquera das URL de imaxes enviadas nas conversas
Comment[hu]=Bélyegkép beágyazása bármely képhivatkozáshoz, amelyet a csevegésben küldenek
Comment[ia]=Incorpora un miniatura de ulle URL de imagine inviate in un conversation
Comment[it]=Include miniature degli URL di immagini inviati in una chat
Comment[kk]=Чаттағы жіберілген кескін URL-інде нобайы болсын
Comment[lt]=Įjungti miniatiūras kiekvieno paveikslėlio URL atsiuntame pokalbyje
Comment[nb]=Bygg inn et minibilde av enhver bilde-URL sent i en prat
Comment[nl]=Een miniatuur of elke verzonden URL van een afbeelding inbedden in een chat
Comment[pl]=Osadź miniaturę jakiegokolwiek adresu URL obrazu w oknie rozmowy
Comment[pt]=Incorporar uma miniatura de qualquer URL de imagens numa conversa
Comment[pt_BR]=Insere uma miniatura de qualquer URL de imagem enviada no bate-papo
Comment[ro]=Înglobează miniatura oricărui URL de imagine trimis într-o discuție
Comment[ru]=Встраивание миниатюры для любой ссылки на изображение
Comment[sk]=Zahrnúť náhľad každej URL poslanej v rozhovore
Comment[sl]=Vstavi sličico kateregakoli poslanega naslova URL, ki je slika, v klepet
Comment[sr]=Угнежђена сличица било којег УРЛ‑а слике у ћаскању
Comment[sr@ijekavian]=Угнијежђена сличица било којег УРЛ‑а слике у ћаскању
Comment[sr@ijekavianlatin]=Ugniježđena sličica bilo kojeg URL‑a slike u ćaskanju
Comment[sr@latin]=Ugnežđena sličica bilo kojeg URL‑a slike u ćaskanju
Comment[sv]=Inbädda en miniatyrbild av alla webbadresser med bilder som skickas i en chatt
Comment[tr]=Sohbette gönderilmiş bir resim URL'sinin küçük resmini göm
Comment[uk]=Вбудовувати мініатюри для всіх адрес зображень, надісланих під час спілкування
Comment[wa]=Ravaler on prévoeyaedje di tolminme kén URL evoyî dins on berdelaedje
Comment[x-test]=xxEmbed a thumbnail of any image URL sent in a chatxx
Comment[zh_CN]=嵌入聊天中图像 URL 的缩略图
Comment[zh_TW]=聊天內傳送影像網址時嵌入其縮圖
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_images
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=images
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
